@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #*******************************************************************************
-# Copyright (c) 2005, 2006 IBM Corporation and others.
+# Copyright (c) 2005, 2007 IBM Corporation and others.
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v1.0
 # which accompanies this distribution, and is available at
@@ -44,7 +44,7 @@ if ($debug) {
 }
 
 $classpath_old = $ENV{CLASSPATH};
-$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.4.0.v20080512.jar:$plugins_dir/org.eclipse.equinox.common_3.4.0.v20080421-2006.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20080604-1400.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar";
+$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.5.0.v20090525.jar:$plugins_dir/org.eclipse.equinox.common_3.5.0.v20090520-1800.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20090507.jar:$plugins_dir/com.ibm.icu.base_4.0.1.v20090415.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar";
 $classpath .= ":$plugin_dir/dstore_extra_server.jar";
 $classpath .= ":$plugin_dir/dstore_core.jar";
 $classpath .= ":$plugin_dir/dstore_miners.jar";
